@@ -2752,6 +2752,24 @@ def test_case_insensitive_nested_optional(env):
     assert s.model_dump() == {'nested': {'BaR': 123, 'FOO': 'string'}}
 
 
+def test_case_insensitive_nested_alias(env):
+    """Ensure case-insensitive environment lookup works with nested aliases."""
+
+    class NestedSettings(BaseModel):
+        FOO: str = Field(..., alias='Foo')
+        BaR: int
+
+    class Settings(BaseSettings):
+        model_config = SettingsConfigDict(env_nested_delimiter='__', case_sensitive=False)
+
+        nEstEd: NestedSettings = Field(..., alias='NesTed')
+
+    env.set('nested__FoO', 'string')
+    env.set('nested__bar', '123')
+    s = Settings()
+    assert s.model_dump() == {'nEstEd': {'BaR': 123, 'FOO': 'string'}}
+
+
 def test_case_insensitive_nested_list(env):
     class NestedSettings(BaseModel):
         FOO: list[str]
